summaryrefslogtreecommitdiff
path: root/devel/cmake
diff options
context:
space:
mode:
authorasau <asau@pkgsrc.org>2014-03-25 07:11:52 +0000
committerasau <asau@pkgsrc.org>2014-03-25 07:11:52 +0000
commit3ab10203179d0698de62814c5569355b732eec53 (patch)
tree574eb50e76b1f19bc50784d2c40dba78ca501b69 /devel/cmake
parentdee3313e1e9889d2c4294ddfa904471ce70f43e5 (diff)
downloadpkgsrc-3ab10203179d0698de62814c5569355b732eec53.tar.gz
Treat DragonFly the same way as FreeBSD.
This fixes build on DragonFly 3.7 as reported by David Shao in PR pkg/48660.
Diffstat (limited to 'devel/cmake')
-rw-r--r--devel/cmake/distinfo4
-rw-r--r--devel/cmake/patches/patch-Source_kwsys_SystemInformation.cxx6
2 files changed, 5 insertions, 5 deletions
diff --git a/devel/cmake/distinfo b/devel/cmake/distinfo
index 38b5ad1835e..cc937398047 100644
--- a/devel/cmake/distinfo
+++ b/devel/cmake/distinfo
@@ -1,4 +1,4 @@
-$NetBSD: distinfo,v 1.57 2014/03/24 20:42:11 asau Exp $
+$NetBSD: distinfo,v 1.58 2014/03/25 07:11:52 asau Exp $
SHA1 (cmake-2.8.12.2.tar.gz) = cca70b307aa32a6a32c72e01fdfcecc84c1c2690
RMD160 (cmake-2.8.12.2.tar.gz) = ee92327c3870f3ae2ea997d0258b0ef141e90525
@@ -7,7 +7,7 @@ SHA1 (patch-CMakeLists.txt) = a37825ad9d1704b9cb716a52148c637d26733898
SHA1 (patch-Modules_FindFreetype.cmake) = 7868ab96cadc011ccb16205382a3cbfa3d159f32
SHA1 (patch-Modules_FindX11.cmake) = e5c9f5fd382effb85ae75fe603de00e5e58d788a
SHA1 (patch-Modules_Platform_SunOS.cmake) = 7a53ae3c902dd69ee22ef9fe0ae2a022d5284f16
-SHA1 (patch-Source_kwsys_SystemInformation.cxx) = 93c66c53dbf91198223d8358cb2da6b8e4b5ece3
+SHA1 (patch-Source_kwsys_SystemInformation.cxx) = 7bad025ea21164f8a4b835665bea87166a5c478c
SHA1 (patch-Utilities_KWIML_CMakeLists.txt) = 4e8cef0eab2ad8cb27cd7076e077bb5e7425a95c
SHA1 (patch-aa) = 97bfad3d2c357e9af01677ba86057b78f0661b9b
SHA1 (patch-ab) = aee3fb2f908aed1ce6e92b7c7ccf5b06f0596502
diff --git a/devel/cmake/patches/patch-Source_kwsys_SystemInformation.cxx b/devel/cmake/patches/patch-Source_kwsys_SystemInformation.cxx
index 52da0c5769f..2c841a8d3a5 100644
--- a/devel/cmake/patches/patch-Source_kwsys_SystemInformation.cxx
+++ b/devel/cmake/patches/patch-Source_kwsys_SystemInformation.cxx
@@ -1,7 +1,7 @@
-$NetBSD: patch-Source_kwsys_SystemInformation.cxx,v 1.6 2014/03/24 20:42:11 asau Exp $
+$NetBSD: patch-Source_kwsys_SystemInformation.cxx,v 1.7 2014/03/25 07:11:52 asau Exp $
* Add more conditional handling for NetBSD, same as others.
* Treat FreeBSD the same way as NetBSD and OpenBSD.
* Treat Solaris same as Linux.
* Use correct cmake define.
@@ -12,7 +12,7 @@ $NetBSD: patch-Source_kwsys_SystemInformation.cxx,v 1.6 2014/03/24 20:42:11 asau
#endif
-#ifdef __FreeBSD__
-+#if defined(__OpenBSD__) || defined(__NetBSD__) || defined(__FreeBSD__)
++#if defined(__OpenBSD__) || defined(__NetBSD__) || defined(__FreeBSD__) || defined(__DragonFly__)
+# include <sys/param.h>
# include <sys/sysctl.h>
-# include <fenv.h>
@@ -1,7 +1,7 @@
* Add more conditional handling for NetBSD, same as others.
-* Treat FreeBSD the same way as NetBSD and OpenBSD.
+* Treat FreeBSD and DragonFly the same way as NetBSD and OpenBSD.
* Treat Solaris same as Linux.
* Use correct cmake define.